@@ -19,10 +19,13 @@
 ##
 
 APP_NAME = 'Awaitable'
-APP_VERSION = '0.2.1'
+APP_VERSION = '0.2.2'
 APP_DESCRIPTION = 'A decorator to asynchronously execute synchronous functions'
-APP_ID = 'awaitable.muflone.com'
-APP_URL = 'http://www.muflone.com/awaitable/'
+APP_DOMAIN = 'awaitable'
+APP_ID = f'{APP_DOMAIN}.muflone.com'
 APP_AUTHOR = 'Fabio Castelli'
 APP_AUTHOR_EMAIL = 'muflone@muflone.com'
-APP_COPYRIGHT = 'Copyright 2022 %s' % APP_AUTHOR
+APP_COPYRIGHT = f'Copyright 2022 {APP_AUTHOR}'
+URL_AUTHOR = 'http://www.muflone.com/'
+URL_APPLICATION = f'{URL_AUTHOR}{APP_DOMAIN}/'
+URL_SOURCES = f'https://github.com/muflone/{APP_DOMAIN}/'
